@@ -6,27 +6,29 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QSEARCH_H
 #define QSEARCH_H
 
-#include "Qt2Base.h"
+#include "QDialogView.h"
+
+namespace lyx {
+namespace frontend {
 
 class ControlSearch;
 class QSearchDialog;
 
-
 ///
 class QSearch
-	: public Qt2CB<ControlSearch, Qt2DB<QSearchDialog> >
+	: public QController<ControlSearch, QView<QSearchDialog> >
 {
 public:
 	///
 	friend class QSearchDialog;
 	///
-	QSearch();
+	QSearch(Dialog &);
 private:
 	/// Apply changes
 	virtual void apply() {}
@@ -35,11 +37,15 @@ private:
 	/// build the dialog
 	virtual void build_dialog();
 
-	void find(string const & str, bool casesens,
+	void find(std::string const & str, bool casesens,
 		  bool words, bool backwards);
 
-	void replace(string const & findstr, string const & replacestr,
-		bool casesens, bool words, bool all);
+	void replace(std::string const & findstr,
+		     std::string const & replacestr,
+		     bool casesens, bool words, bool backwards, bool all);
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QSEARCH_H
